@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import json
+import re
 from typing import Any, List, Optional, Union
 
 import grpc  # type: ignore
@@ -26,6 +27,7 @@ from assertionengine import (
     list_verify_assertion,
     verify_assertion,
 )
+from robot.utils import DotDict  # type: ignore
 
 from ..assertion_engine import with_assertion_polling
 from ..base import LibraryComponent
@@ -209,6 +211,7 @@ class Getters(LibraryComponent):
         | ${text} =    `Get Text`    id=important    ==    Important text    # Returns element text with assertion.
         | ${text} =    `Get Text`    //input         ==    root              # Returns input element text with assertion.
         """
+        self.presenter_mode(selector, self.strict_mode)
         response = self._get_text(selector)
         logger.debug(response.log)
         formatter = self.keyword_formatters.get(self.get_text)
@@ -262,6 +265,7 @@ class Getters(LibraryComponent):
         | `Get Property`    h1    innerText    ==    Login Page
         | ${property} =    `Get Property`    h1    innerText
         """
+        self.presenter_mode(selector, self.strict_mode)
         with self.playwright.grpc_channel() as stub:
             response = stub.GetDomProperty(
                 Request().ElementProperty(
@@ -328,6 +332,7 @@ class Getters(LibraryComponent):
         | `Get Attribute`   id=enabled_button    something    evaluate    value is not None    # PASS =>  returns: True
         | `Get Attribute`   id=enabled_button    disabled     evaluate    value is None        # PASS =>  returns: True
         """
+        self.presenter_mode(selector, self.strict_mode)
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElementAttribute(
                 Request().ElementProperty(
@@ -479,6 +484,7 @@ class Getters(LibraryComponent):
         | `Get Select Options`     //select[2]    validate  [v["label"] for v in value] == ["Email", "Mobile"]
         | `Get Select Options`   select#names     validate  any(v["label"] == "Mikko" for v in value)
         """
+        self.presenter_mode(selector, self.strict_mode)
         with self.playwright.grpc_channel() as stub:
             response = stub.GetSelectContent(
                 Request().ElementSelector(selector=selector, strict=self.strict_mode)
@@ -707,7 +713,7 @@ class Getters(LibraryComponent):
         with self.playwright.grpc_channel() as stub:
             response = stub.GetViewportSize(Request().Empty())
             logger.info(response.log)
-            parsed = json.loads(response.json)
+            parsed = DotDict(json.loads(response.json))
             logger.debug(parsed)
             if self.keyword_formatters.get(self.get_viewport_size):
                 logger.warn("Formatter is not supported by Get Viewport Size keyword.")
@@ -729,6 +735,151 @@ class Getters(LibraryComponent):
                     message,
                 )
 
+    @keyword(tags=("Getter", "PageContent"))
+    def get_table_cell_element(self, table: str, column: str, row: str) -> str:
+        """Returns the Web Element that has the same column index and same row index as the selected elements.
+
+        ``table`` selector must select the ``<table>`` element that contains both selected elements
+
+        ``column`` selector can select any ``<th>`` or ``<td>`` element or one of their descendants.
+
+         ``row`` selector can select any ``<tr>`` element or one of their descendant like ``<td>`` elements.
+
+         ``column`` and ``row`` can also consume index numbers instead of selectors.
+         Indexes are starting from ``0`` and ``-1`` is specific for the last element.
+
+
+        Selectors for ``column`` and ``row`` are directly appended to ``table`` selector like this: ``f"{table} >> {row}" .``
+
+        | = GitHub = |   = Slack =      | = Real Name =   |
+        | mkorpela   | @mkorpela        | Mikko Korpela   |
+        | aaltat     | @aaltat          | Tatu Aalto      |
+        | xylix      | @Kerkko Pelttari | Kerkko Pelttari |
+        | Snooz82    | @René            | René Rohner     |
+
+
+        Example:
+        | ${table}=    Set Variable    id=Get Table Cell Element >> div.kw-docs table
+        | ${e}=    `Get Table Cell Element`    ${table}    "Real Name"    "aaltat"   # Returns element with text ``Tatu Aalto``
+        | Get Text    ${e}    ==    Tatu Aalto
+        | ${e}=    `Get Table Cell Element`    ${table}    "Slack"    "Mikko Korpela"   # Returns element with text ``@mkorpela``
+        | Get Text    ${e}    ==    @mkorpela
+        | ${e}=    `Get Table Cell Element`    ${table}    "mkorpela"    "Kerkko Pelttari"   # column does not need to be in row 0
+        | Get Text    ${e}    ==    @mkorpela
+        | ${e}=    `Get Table Cell Element`    ${table}    2    -1   # Index is also directly possible
+        | Get Text    ${e}    ==    René Rohner
+        """
+        node_name = str(self.library.execute_javascript("e => e.nodeName", table))
+        if node_name != "TABLE":
+            raise ValueError(
+                f"Selector {table} must select a <table> element but selects <{node_name.lower()}>."
+            )
+        column_idx = (
+            column
+            if re.fullmatch(r"-?\d+", column)
+            else self.get_table_cell_index(f"{table} >> {column}")
+        )
+        row_idx = (
+            row
+            if re.fullmatch(r"-?\d+", row)
+            else self.get_table_row_index(f"{table} >> {row}")
+        )
+        return self.get_element(
+            f"{table} >> > * > tr >> nth={row_idx} >> > * >> nth={column_idx}"
+        )
+
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
+    @with_assertion_polling
+    def get_table_cell_index(
+        self,
+        selector: str,
+        assertion_operator: Optional[AssertionOperator] = None,
+        expected_value: Union[int, str] = 0,
+        message: Optional[str] = None,
+    ) -> Any:
+        """Returns the index (0 based) of a table cell within its row.
+
+        ``selector`` can select any ``<th>`` or ``<td>`` element or one of their descendants.
+        See the `Finding elements` section for details about the selectors.
+
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
+
+        ``expected_value`` Expected value for the counting
+
+        ``message`` overrides the default error message for assertion.
+
+        Example:
+        | ${table}=    Set Variable    id=`Get Table Cell Element` >> div.kw-docs table   #Table of keyword `Get Table Cell Element`
+        | ${idx}=    `Get Table Cell Index`    ${table} >> "Real Name"
+        | Should Be Equal    ${idx}    ${2}
+        | `Get Table Cell Index`    ${table} >> "@aaltat"    ==    1
+
+        Optionally asserts that the index matches the specified assertion. See
+        `Assertions` for further details for the assertion arguments.
+        By default assertion is not done."""
+        with self.playwright.grpc_channel() as stub:
+            response = stub.GetTableCellIndex(
+                Request().ElementSelector(selector=selector, strict=False)
+            )
+            count = response.body
+            if self.keyword_formatters.get(self.get_table_cell_index):
+                logger.warn(
+                    "Formatter is not supported by Get Table Cell Index keyword."
+                )
+            return float_str_verify_assertion(
+                int(count),
+                assertion_operator,
+                expected_value,
+                f"Element cell index for selector `{selector}` is",
+                message,
+            )
+
+    @keyword(tags=("Getter", "Assertion", "PageContent"))
+    @with_assertion_polling
+    def get_table_row_index(
+        self,
+        selector: str,
+        assertion_operator: Optional[AssertionOperator] = None,
+        expected_value: Union[int, str] = 0,
+        message: Optional[str] = None,
+    ) -> Any:
+        """Returns the index (0 based) of a table row.
+
+        ``selector`` can select any ``<th>`` or ``<td>`` element or one of their descendants.
+        See the `Finding elements` section for details about the selectors.
+
+        ``assertion_operator`` See `Assertions` for further details. Defaults to None.
+
+        ``expected_value`` Expected value for the counting
+
+        ``message`` overrides the default error message for assertion.
+
+        Example:
+        | ${table}=    Set Variable    id=`Get Table Cell Element` >> div.kw-docs table   #Table of keyword `Get Table Cell Element`
+        | ${idx}=    `Get Table Row Index`    ${table} >> "@René"
+        | Should Be Equal    ${idx}    ${4}
+        | `Get Table Row Index`    ${table} >> "@aaltat"    ==    2
+
+        Optionally asserts that the index matches the specified assertion. See
+        `Assertions` for further details for the assertion arguments.
+        By default assertion is not done."""
+        with self.playwright.grpc_channel() as stub:
+            response = stub.GetTableRowIndex(
+                Request().ElementSelector(selector=selector, strict=False)
+            )
+            count = response.body
+            if self.keyword_formatters.get(self.get_table_row_index):
+                logger.warn(
+                    "Formatter is not supported by Get Table Row Index keyword."
+                )
+            return float_str_verify_assertion(
+                int(count),
+                assertion_operator,
+                expected_value,
+                f"Element row index for selector `{selector}` is",
+                message,
+            )
+
     @keyword(tags=("Getter", "PageContent"))
     def get_element(self, selector: str) -> str:
         """Returns a reference to a Playwright [https://playwright.dev/docs/api/class-locator|Locator].
@@ -813,11 +964,12 @@ class Getters(LibraryComponent):
         `Assertions` for further details for the assertion arguments. By default assertion
         is not done.
         """
+        self.presenter_mode(selector, self.strict_mode)
         with self.playwright.grpc_channel() as stub:
             response = stub.GetStyle(
                 Request().ElementSelector(selector=selector, strict=self.strict_mode)
             )
-        parsed = json.loads(response.json)
+        parsed = DotDict(json.loads(response.json))
         formatter = self.keyword_formatters.get(self.get_style)
         if key == "ALL":
             if formatter:
@@ -890,7 +1042,7 @@ class Getters(LibraryComponent):
             response = stub.GetBoundingBox(
                 Request.ElementSelector(selector=selector, strict=self.strict_mode)
             )
-        parsed = json.loads(response.json)
+        parsed = DotDict(json.loads(response.json))
         logger.debug(f"BoundingBox: {parsed}")
         if self.keyword_formatters.get(self.get_boundingbox):
             logger.warn("Formatter is not supported by Get Boundingbox keyword.")
@@ -948,7 +1100,7 @@ class Getters(LibraryComponent):
         | ${scroll_size}=    `Get Scroll Size`    id=keyword-shortcuts-container  # unfiltered element
         | Log                ${scroll_size}                                     # {'width': 253, 'height': 3036}
         """
-        scroll_size = dict()
+        scroll_size = DotDict()
         scroll_size["width"] = exec_scroll_function(self, "scrollWidth", selector)
         scroll_size["height"] = exec_scroll_function(self, "scrollHeight", selector)
         if self.keyword_formatters.get(self.get_scroll_size):
@@ -1011,7 +1163,7 @@ class Getters(LibraryComponent):
 
         See `Get BoundingBox` or `Get Scroll Size` for examples.
         """
-        scroll_position = dict()
+        scroll_position = DotDict()
         scroll_position["top"] = exec_scroll_function(self, "scrollTop", selector)
         scroll_position["left"] = exec_scroll_function(self, "scrollLeft", selector)
         client_size = self.get_client_size(selector)
@@ -1071,7 +1223,7 @@ class Getters(LibraryComponent):
 
         See `Get BoundingBox` or `Get Scroll Size` for examples.
         """
-        client_size = dict()
+        client_size = DotDict()
         client_size["width"] = exec_scroll_function(self, "clientWidth", selector)
         client_size["height"] = exec_scroll_function(self, "clientHeight", selector)
         if self.keyword_formatters.get(self.get_client_size):
@@ -1208,6 +1360,7 @@ class Getters(LibraryComponent):
             return f.name if isinstance(f, ElementState) else f
 
         assertion_expected_str = [convert_str(flag) for flag in assertion_expected]
+        self.presenter_mode(selector, self.strict_mode)
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElementStates(
                 Request.ElementSelector(selector=selector, strict=self.strict_mode)
